#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from persistent import Persistent
from zope.container.contained import Contained
from zope.interface import Interface
from zope.schema.fieldproperty import FieldProperty

from pyams_almond_theme.component.gallery.portlet.interfaces import \
    IGalleryPortletCarouselRendererSettings
from pyams_content.component.gallery.portlet.interfaces import IGalleryPortletSettings
from pyams_default_theme.component.gallery.portlet import GalleryPortletBaseRenderer
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config


__docformat__ = 'restructuredtext'

from pyams_almond_theme import _


@factory_config(provided=IGalleryPortletCarouselRendererSettings)
class GalleryPortletCarouselRendererSettings(Persistent, Contained):
    """Gallery portlet carousel renderer settings"""

    css_class = FieldProperty(IGalleryPortletCarouselRendererSettings['css_class'])
    thumb_selection = FieldProperty(IGalleryPortletCarouselRendererSettings['thumb_selection'])
    automatic_slide = FieldProperty(IGalleryPortletCarouselRendererSettings['automatic_slide'])
    slide_interval = FieldProperty(IGalleryPortletCarouselRendererSettings['slide_interval'])
    fade_effect = FieldProperty(IGalleryPortletCarouselRendererSettings['fade_effect'])
    display_controls = FieldProperty(IGalleryPortletCarouselRendererSettings['display_controls'])
    display_indicators = FieldProperty(IGalleryPortletCarouselRendererSettings['display_indicators'])
    display_captions = FieldProperty(IGalleryPortletCarouselRendererSettings['display_captions'])
    enable_touch = FieldProperty(IGalleryPortletCarouselRendererSettings['enable_touch'])


@adapter_config(name='carousel',
                context=(IPortalContext, IPyAMSLayer, Interface, IGalleryPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/gallery-carousel.pt', layer=IPyAMSLayer)
class GalleryPortletCarouselRenderer(GalleryPortletBaseRenderer):
    """Gallery portlet carousel renderer"""

    label = _("Gallery carousel")

    settings_interface = IGalleryPortletCarouselRendererSettings
