#
# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyams_almond_theme.layer import IPyAMSAlmondLayer
from pyams_content.component.paragraph.interfaces.html import IHTMLParagraph
from pyams_content.features.renderer import IContentRenderer
from pyams_default_theme.component.paragraph.html import \
    HTMLParagraphDefaultRenderer as HTMLParagraphDefaultRendererBase, \
    HTMLParagraphWithLogosRenderer
from pyams_template.template import override_template, template_config
from pyams_utils.adapter import adapter_config


@adapter_config(name='default',
                context=(IHTMLParagraph, IPyAMSAlmondLayer),
                provides=IContentRenderer)
@template_config(template='templates/html-default.pt',
                 layer=IPyAMSAlmondLayer)
class HTMLParagraphDefaultRenderer(HTMLParagraphDefaultRendererBase):
    """HTML paragraph default renderer"""

    def get_padding(self, settings):
        result = []
        for device in ('xs', 'sm', 'md', 'lg'):
            padding = getattr(settings, '{}_horizontal_padding'.format(device))
            if padding is not None:
                prefix = '' if device == 'xs' else '{}-'.format(device)
                result.append('col-{0}{1} offset-{0}{2}'.format(prefix,
                                                                12 - (padding * 2),
                                                                padding))
        return ' '.join(result)


override_template(context=HTMLParagraphWithLogosRenderer,
                  template='templates/html-logos.pt',
                  layer=IPyAMSAlmondLayer)
