#
# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyams_almond_theme.layer import IPyAMSAlmondLayer
from pyams_content.component.verbatim.interfaces import IVerbatimParagraph
from pyams_content.features.renderer import IContentRenderer
from pyams_default_theme.component.verbatim.paragraph import \
    DefaultVerbatimParagraphRenderer as DefaultVerbatimParagraphRendererBase, \
    LeftVerbatimParagraphRenderer, RightVerbatimParagraphRenderer
from pyams_template.template import override_template, template_config
from pyams_utils.adapter import adapter_config


@adapter_config(name='default',
                context=(IVerbatimParagraph, IPyAMSAlmondLayer),
                provides=IContentRenderer)
@template_config(template='templates/verbatim-default.pt',
                 layer=IPyAMSAlmondLayer)
class DefaultVerbatimParagraphRenderer(DefaultVerbatimParagraphRendererBase):
    """Default verbatim paragraph renderer"""

    def get_padding(self, settings):
        result = []
        for device in ('xs', 'sm', 'md', 'lg'):
            padding = getattr(settings, '{}_horizontal_padding'.format(device))
            if padding is not None:
                prefix = '' if device == 'xs' else '{}-'.format(device)
                result.append('col-{0}{1} offset-{0}{2}'.format(prefix,
                                                                12 - (padding * 2),
                                                                padding))
        return ' '.join(result)


override_template(context=LeftVerbatimParagraphRenderer,
                  template='templates/verbatim-left.pt',
                  layer=IPyAMSAlmondLayer)


override_template(context=RightVerbatimParagraphRenderer,
                  template='templates/verbatim-right.pt',
                  layer=IPyAMSAlmondLayer)
