#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from pyams_almond_theme.features.footer import AlmondThemeFooterRendererSettings, \
    IAlmondThemeFooterRendererSettings
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.footer import IFooterRenderer, IFooterRendererSettings, \
    IFooterSettings, IFooterTarget
from pyams_content.features.share.interfaces import ISocialShareInfo
from pyams_default_theme.features.footer.skin import BaseFooterRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config


__docformat__ = 'restructuredtext'

from pyams_almond_theme import _


ALMOND_FOOTER_RENDERER_NAME = 'PyAMS almond footer'


@adapter_config(name=ALMOND_FOOTER_RENDERER_NAME,
                context=(IFooterTarget, IPyAMSLayer),
                provides=IFooterRenderer)
@adapter_config(name=ALMOND_FOOTER_RENDERER_NAME,
                context=(IFooterSettings, IPyAMSLayer),
                provides=IFooterRenderer)
@template_config(template='templates/footer.pt',
                 layer=IPyAMSLayer)
class AlmondThemeFooterRenderer(BaseFooterRenderer):
    """Almond theme footer renderer"""

    name = ALMOND_FOOTER_RENDERER_NAME
    label = _("PyAMS almond theme footer")
    weight = 5

    settings_key = 'PyAMS::almond'
    settings_interface = IAlmondThemeFooterRendererSettings

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)

    def get_social_info(self):
        return ISocialShareInfo(self.request.root, None)


@adapter_config(context=AlmondThemeFooterRenderer,
                provides=IFooterRendererSettings)
def almond_theme_footer_renderer_settings_factory(context):
    """Almond theme footer renderer settings factory"""
    return AlmondThemeFooterRendererSettings()
