#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from z3c.form.field import Fields

from pyams_almond_theme.features.footer import IAlmondThemeFooterLegalsMenu, \
    IAlmondThemeFooterMenusContainer, \
    IAlmondThemeFooterRendererSettings
from pyams_content.features.footer.zmi import FooterSettingsRendererSettingsEditForm
from pyams_content.features.menu.zmi import IMenuLinksView, IMenusView, LinksTable, MenuLinksView, \
    MenusTable, \
    MenusView
from pyams_form.interfaces.form import IInnerSubForm
from pyams_portal.interfaces import MANAGE_TEMPLATE_PERMISSION
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.adapter import adapter_config
from pyams_zmi.form import InnerAdminEditForm


__docformat__ = 'restructuredtext'

from pyams_almond_theme import _


@adapter_config(name='simple-footer-properties',
                context=(IAlmondThemeFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
class AlmondThemeFooterPropertiesEditForm(InnerAdminEditForm):
    """Almond theme footer properties edit form"""

    legend = None
    edit_permission = MANAGE_TEMPLATE_PERMISSION
    weight = 1

    fields = Fields(IAlmondThemeFooterRendererSettings)


#
# Footer menus table view
#

@adapter_config(name='almond-footer-menus',
                context=(IAlmondThemeFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++menus',
                context=(IAlmondThemeFooterMenusContainer, IPyAMSLayer),
                provides=IMenusView)
class AlmondThemeFooterMenusView(MenusView):
    """Almond theme footer menus view"""

    title = _("Footer menus")

    table_class = MenusTable
    weight = 10


#
# Footer legal links table view
#

class LegalLinksTable(LinksTable):
    """Legal links associations table"""

    associations_name = 'legals'


@adapter_config(name='almond-footer-legals',
                context=(IAlmondThemeFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++legals',
                context=(IAlmondThemeFooterLegalsMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class AlmondThemeFooterLegalsView(MenuLinksView):
    """Almond theme footer legals view"""

    title = _("Legal links menus")

    table_class = LegalLinksTable
    weight = 15
